<?php
/**
 * Example to show how to use SBBS Lib. 
 * Show 
 *  - Menu
 *  - Register to subscription 
 *  - Unregister from subscription
 *  - Check user status
 *  
 * Example class
 * @package ExampleProject
 * @subpackage module
 * 
 * @author Liutauras Rickus <lr@vero.lt>
 *
 */

include_once(dirname(__FILE__).'/../../lib/MBS.class.php');

/**
 * ModuleSbbs
 * 
 * @package ExampleProject
 * @subpackage module
 * @author Liutauras Rickus <lr@vero.lt>
 */
class ModuleSbbsWeb {
    
    /**
     * Internal SBBS object
     * @access protected
     * @var SBBS
     */
    var $sbbs = null;
    
    /**
     * Internal Identify object
     * @access protected
     *
     * @var Identify
     */
    var $identify = null;
    
    /**
     * This action
     * @access protected
     *
     * @var array
     */
    var $actions = array();
        
    /**
     * Internal used data
     * @access protected
     *
     * @var mixed
     */
    var $data = '';
    
    /**
     * SBBS subscription users
     * @var string
     */
    var $users = 'sbbs_users.log';
    
    /**
     * Allowed users
     * @var array
     */
    var $allowedUsers = array('a', 'b', 'c');
    
    /**
     * MBSLib for notify authorization
     * @var object
     */
    var $mbsLib = null;
    
    /**
     * Constructor
     *
     * @param SBBS $mbs - from lib
     * @return ModuleMbs
     */
    function ModuleSbbsWeb( &$sbbs, &$identify ) {
    	$this->sbbs = &$sbbs;
        $this->identify = &$identify;
        $this->actions = explode('.', $_REQUEST['act']);
        $this->mbsLib = new MBSBase();
		$this->mbsLib->setSecretKey('SuperSecure');
    }
    
    function getUserByNick($nick)
    {
        if (in_array($nick, $this->allowedUsers))
        {
        	$users = file_get_contents($this->users);
        	
   			if (!empty($users)) {
            	$users = unserialize($users);
            	
            	if (!empty($users[$nick])) {
            	    return $users[$nick];
            	}
            }
        }
        
        return false;
    }
    
    function getUserList()
    {
    	$users = file_get_contents($this->users);
    	
		if (!empty($users)) {
        	$users = unserialize($users);
		} else {
		    $users = array();
		}
		
		return $users;
    }
    
    function notifyAction()
    {
        // Loginame kad atejo zinute (data, URL, GET parametrai)
        file_put_contents('tmp.log', date('Y-m-d H:i:s ') . print_r($_SERVER['REQUEST_URI'], true) . "\n" . print_r($_GET, true), FILE_APPEND);
        
        $config['servers'] = array('213.226.139.33', '213.226.139.42', '213.226.139.43', '193.105.49.4', '193.105.49.5', '192.168.1.39');
        
        if ( in_array( $_SERVER['REMOTE_ADDR'], $config['servers'] ) ) {
        	if( $this->mbsLib->verifyArrayHigh($_GET) ) {
        		// Nusiskaitome pagrindinius pranesimo duomenis
        		$action = $_GET['action'];
        		$mbs_service_id = $_GET['serviceID'];
        		$mbs_account_id = $_GET['mbs_account_id'];
        		$mbs_account_phone = $_GET['mbs_account_phone'];
        		
        		$nick = $_GET['sdata'];
        		$userList = $this->getUserList();
        		$user = $this->getUserByNick($nick);
        		
        		// Paslaugos logika
        		switch ($action) {
        		    case 'sms':      
		                if ((!$user && in_array($nick, $this->allowedUsers)) || $user != false) {
		                	if (!$user) {
    		                    $userList[$nick] = array(
    		                							'date' => date('Y-m-d H:i'),
    		                							'state' => 'inactive',
    		                							'credits' => 0
    		                						);
    		                	file_put_contents($this->users, serialize($userList));
		                	}
		                	
		                	$response = array('OK');
		                } else {
		                    $response = array('ERRORNeteisingas vartotojo vardas');
		                }
		                
		                /** Loginame "Vartotojas atsiunte SMS zinute (user data, user status, kreditai) ... **/
        		        file_put_contents('tmp.log', date('Y-m-d H:i:s ') . "Vartotojas atsiunte SMS zinute\n" . print_r($userList[$nick], true), FILE_APPEND);
        		    break;
        		    
        		    case 'approve':
        		        if ($user != false)
		                {							
		                	$userList[$nick]['state'] = 'active';
		                	$userList[$nick]['date'] = date('Y-m-d H:i');
		                	
		                	file_put_contents($this->users, serialize($userList));
		                	
		                	$response = array('OK');
		                } else {
	                		$response = array('ERROR', 'NOT_MEMBER');
	                	}
        		        
        			    /** Loginame "Vartotojas patvirtino periodine prenumerata (user data, user status, kreditai) ... **/
        		        file_put_contents('tmp.log', date('Y-m-d H:i:s ') . "Vartotojas patvirtino periodine prenumerata\n" . print_r($userList[$nick], true), FILE_APPEND);
        			break;
        		    
        			case 'register':
        			case 'resume':	                	
                		if ($user != false)
		                {
							$userList[$nick]['credits'] += 10;
							
		                	$userList[$nick]['state'] = 'active';
		                	$userList[$nick]['date'] = date('Y-m-d H:i');
		                	
		                	file_put_contents($this->users, serialize($userList));
		                	
		                	$response = array('OK');
		                } else {
	                		$response = array('ERROR', 'NOT_MEMBER');
	                	}
        			    
        				/** Loginame "Vartotojui suteikiama VIP prieiga (user data, user status, kreditai, prideti 10 kreditu) ... **/
	                	file_put_contents('tmp.log', date('Y-m-d H:i:s ') . "Vartotojui suteikiama VIP prieiga\n" . print_r($userList[$nick], true), FILE_APPEND);
        			break;
        
        			case 'pay':
        			case 'renew':
        		        if ($user != false)
		                {
							$userList[$nick]['credits'] += 10;
							
		                	$userList[$nick]['state'] = 'active';
		                	$userList[$nick]['date'] = date('Y-m-d H:i');
		                	
		                	file_put_contents($this->users, serialize($userList));
		                	
		                	$response = array('OK');
		                } else {
	                		$response = array('ERROR', 'NOT_MEMBER');
	                	}
	                	
        				/** Loginame "Ivyko sekmingas pratesimas (user data, user status, kreditai, prideti 10 kreditu) ... **/
        				file_put_contents('tmp.log', date('Y-m-d H:i:s ') . "Ivyko sekmingas pratesimas\n" . print_r($userList[$nick], true), FILE_APPEND);
        			break;
        			
        			case 'unregister':
        			case 'remove':
        			case 'suspend':        		        
        				if ($user != false)
		                {
		                	$userList[$nick]['state'] = 'inactive';
		                	file_put_contents($this->users, serialize($userList));
		                	
		                	$response = array('OK');
		                } else {
	                		$response = array('ERROR', 'NOT_MEMBER');
	                	}
	                	
	                	/** Loginame "Vartotojui sustabdoma VIP prieiga (user data, user status, kreditai) ... **/
        		        file_put_contents('tmp.log', date('Y-m-d H:i:s ') . "Vartotojui sustabdoma VIP prieiga\n" . print_r($userList[$nick], true), FILE_APPEND);
        			break;
        			
        			default:
        				$response = array('ERROR', 'Nezinomas pranesimo tipas');
        			break;
        		}
        	// Sufalsifikuoti GET parametrai
        	} else {
        		$response = array('ERROR', 'Siuntejas ne MBS');
        	}
        // Nežinomo serverio GET parametrai
        } else {
        	$response = array('ERROR', 'Nezinomas serveris');
        }
        
        // Paslaugos atsakymas vartotojui
        echo implode(';', array_map('urlencode', $response));
        
        // Loginame koki atsakyma issiunteme (data, atsakymas)
        file_put_contents('tmp.log', date('Y-m-d H:i:s ') . implode(';', array_map('urlencode', $response)) . "\n", FILE_APPEND);
    }
    
    /**
     * Main action for module
     *
     */
    function parseAction() {
        if ($this->actions[0] != 'sbbsWeb') {
            return false;
        }
        
        switch ($this->actions[1]) {
            case 'register':
                if( !empty($_POST['register_submit']) ) {
                    $userCode = md5(trim($_POST['phone']));
                    $userCode = substr($userCode, 0, 5);
                    $this->data['userCode'] = $userCode;
                }
                break;
                                
            // Show login form
            case 'login':
            	$login_error = null;
                // If user submits form
                if( !empty($_POST['login_submit']) ) {
                    $login_nick = strtolower(trim($_POST['nick']));
                    
                    if( !empty($login_nick)) {
                        $users = file_get_contents($this->users);
                        
                        if (!empty($users)) {
                        	$users = unserialize($users);
                        } else {
                        	$users = array();
                        	$login_error = true;
                        }
                        
                        if( $users[$login_nick]['state']=='active') {
                        	$users[$login_nick]['user'] = $login_nick;
                            $_SESSION['user'] = array(
                                'logged'=> true,
                                'info'  => $users[$login_nick],
                            );
                        } else {
                        	$login_error = true;
                        }
                        
                    } else {
                    	$login_error = true;
                    }
                                        
                    if ($login_error != true) {
                    	header('Location: ?act=sbbsWeb.logged');
                    } else {
                    	$this->data['loginError'] = true;
                    } 
                }
                break;

            case 'logout':
                unset($_SESSION['user']);
                break;
            
            case 'notify':
                $this->notifyAction();
            	break;
        }       
        return true;
    }
    

    /**
     * Main display for module. It must be change by template.
     */
    function showBlock() {
        foreach ($this->actions as $key => $item) {
            $selected[$key][$item] = 'selected';
        }
    	if ($this->actions[0] != 'sbbsWeb') {
            $selected = null;
        }
        ?>
    <table>
    <tr>
        <td><div class="bold"><?php lang('sbbs_web');?></div></td>
    </tr>
    <tr>
        <td>
            <table style="padding-left: 15px;">
                <!-- User Pre test -->
                <?php if( !empty($selected[1]['register']) && !$_SESSION['user']['logged'] && empty($this->data['userCode']) ): ?>
                <tr><td>
                    <form action="?act=sbbsWeb.register" method="POST">
                        <?php lang('login_phone')?>:<br/>
                        <input name="phone" value="" /><br/>
                        <input name="register_submit" value="<?php lang('register')?>" type="submit" /><br/>
                    </form>
                </td></tr>
                <?php endif; ?>
                <tr>
                    <td><a href="?act=sbbsWeb.login" class="<?php echo $selected[1]['login']; ?>"><?php lang('login')?></a></td>
                </tr>
                <?php if( !empty($selected[1]['login']) && !$_SESSION['user']['logged'] ): ?>
                <tr><td>
                    <?php if ($this->data['loginError'] == true): ?>
                    <strong>Norėdami gauti slaptažodį, siųskite SMS su tekstu "PLV <?php echo $_POST['nick'] ?>" numeriu 1850</strong>
                    <?php endif;?>
                    <form action="?act=sbbsWeb.login" method="POST">
                        <?php lang('login_user')?>:<br/>
                        <input type="radio" name="nick" value="a" /> a<br />
                        <input type="radio" name="nick" value="b" /> b<br />
                        <input type="radio" name="nick" value="c" /> c<br />
                        <input name="login_submit" value="<?php lang('login')?>" type="submit" /><br/>
                    </form>
                </td></tr>
                <?php endif; ?>
                <tr>
                    <td><a href="?act=sbbsWeb.logged" class="<?php echo $selected[1]['logged']; ?>"><?php lang('check_status')?></a></td>
                </tr>
                <?php if( !empty($selected[1]['logged']) ): ?>
                <tr>
                    <td>
                        <?php if( $_SESSION['user']['logged'] ): ?>
                            <pre><?php print_r($_SESSION['user']['info']); ?></pre><br />
                            <a href="tmp.log">Pranešimai</a><br />
                        <?php else: ?>
                            <?php lang('login_error') ?>
                        <?php endif;?>
                    </td>
                </tr>
                <?php endif; ?>
                <tr>
                    <td><a href="?act=sbbsWeb.logout" class="<?php echo $selected[1]['logout']; ?>"><?php lang('logout')?></a></td>
                </tr>
            </table>
        </td>
    </tr>
    </table>        
        <?php
    }
    
}
?>